/***************************************************************************
Copyright (c) 2006 Peter Korzuszek, Damian Rakowski, KateOS Project
 
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 
*Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
 
*Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS
IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE. 
****************************************************************************/

#ifndef LIBUPDATEOS_REPO_H
#define LIBUPDATEOS_REPO_H

#include <sturl.h>
#include <sttime.h>
#include <stassert.h>
#include <ststring.h>
#include <stvaluelist.h>

#include "package.h"
#include "config.h"

namespace updateos
{

// repo of remote packages
// def:
// shortName: like gcc
// longName: like gcc-4.0.1-i486-2

const int ErRepoSyntax = 0; // list syntax error

class Repo
{
	
	public:
		Repo();
		
		void setUrl( const StString& url );
		bool setSaveDirectory( const StString& path );
		
		bool download(){ return url.download(); }
		bool downloaded(){ return !url.isDownloading(); }
		bool downloadSucceed(){ return url.downloadSucceed(); }
		
		/// read downloaded list
		bool read();
		
		/** 
			True if package exists in repo.
			\param shortName short name of requested package (like gcc)
		*/
		bool exists( const StString& shortName );
		//StString getLongName( const StString& shortName );
		
		Package getNewestPackage( const StString& shortName );
		
		/// Returns build time of package.
		/// \param shortName short name of requested package (like gcc) 
		StTime getTime( const StString& shortName );
		
		StString getServerAddr();
		
		StValueList<Package> getPackages(){ return packages; }
		
		void clear(){ serverAddr.clear(); packages.clear(); }
	
	private:
		StUrl url;
		StString serverAddr;
		StValueList<Package> packages;
		static int count;
	
}; // class

} // namespace

#endif //LIBUPDATEOS_REPO_H
